==> qtjambi-quick-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiQuick/QQuickRenderControl_shell.h <==
#ifndef QQUICKRENDERCONTROL_SHELL_H
#define QQUICKRENDERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qquickrendercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/6.6.0/QtGui/rhi/qrhi.h>
#include <QtGui/qwindow.h>
#include <QtQuick/qquickwindow.h>
#include <QtJambi/RegistryAPI>


class QQuickRenderControl_shell : public QQuickRenderControl, public QtJambiShellInterface
{
public:
    QQuickRenderControl_shell(QObject* parent0 = nullptr);
    ~QQuickRenderControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QWindow* renderWindow(QPoint* offset0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickRenderControl_access : public QQuickRenderControl
{
    jobject __qt_renderWindow_QPoint_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0);
};

#endif // QQUICKRENDERCONTROL_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiQuick/QQuickRenderControl_shell.h <==
#ifndef QQUICKRENDERCONTROL_SHELL_H
#define QQUICKRENDERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickrendercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qwindow.h>
#include <QtGui/rhi/qrhi.h>
#include <QtQuick/qquickwindow.h>
#include <QtJambi/RegistryAPI>


class QQuickRenderControl_shell : public QQuickRenderControl, public QtJambiShellInterface
{
public:
    QQuickRenderControl_shell(QObject* parent0 = nullptr);
    ~QQuickRenderControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QWindow* renderWindow(QPoint* offset0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickRenderControl_access : public QQuickRenderControl
{
    jobject __qt_renderWindow_QPoint_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0);
};

#endif // QQUICKRENDERCONTROL_SHELL_H
